# -*- coding: utf-8 -*-
# Generated by Django 1.9.12 on 2018-02-01 09:03
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('contentstore', '0007_auto_20171102_0950'),
        ('subscriptions', '0007_auto_20171102_0950'),
    ]

    operations = [
        migrations.CreateModel(
            name='ResendRequest',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('received_at', models.DateTimeField(auto_now_add=True)),
                ('outbound', models.UUIDField(null=True)),
                ('message', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='resend_requests', to='contentstore.Message')),
                ('subscription', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='subscriptions.Subscription')),
            ],
        ),
    ]



import os
import requests
import paramiko

from celery.task import Task
from django.conf import settings
from sftpclone import sftpclone

from .models import BinaryContent
from subscriptions.tasks import make_absolute_url


class SyncAudioMessages(Task):

    def _get_existing_files(self, root, host, username, password, port):
        ssh = paramiko.SSHClient()
        ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
        ssh.connect(host, username=username, password=password, port=port)
        ftp = ssh.open_sftp()
        existing_files = ftp.listdir(root)
        return existing_files

    def run(self, **kwargs):
        if settings.AUDIO_FTP_HOST:

            src = '{}/{}/'.format(settings.BASE_DIR, settings.MEDIA_ROOT)

            root = settings.AUDIO_FTP_ROOT
            host = settings.AUDIO_FTP_HOST
            username = settings.AUDIO_FTP_USER
            password = settings.AUDIO_FTP_PASS
            port = int(settings.AUDIO_FTP_PORT)

            existing_files = self._get_existing_files(
                root, host, username, password, port)

            delete_files = []

            files = BinaryContent.objects.all()
            for item in files.iterator():

                if item.content.name not in existing_files:
                    r = requests.get(make_absolute_url(item.content.url))

                    local_path = '{}{}'.format(src, item.content.name)
                    with open(local_path, "wb") as f:
                        f.write(r.content)

                    delete_files.append(local_path)

            cloner = sftpclone.SFTPClone(
                src,
                "{}:{}@{}:{}".format(username, password, host, root),
                port=port,
                delete=False
            )

            cloner.run()

            for item in delete_files:
                os.remove(item)


sync_audio_messages = SyncAudioMessages()



from django.core.management.base import BaseCommand
from django.forms.models import model_to_dict

from subscriptions.models import Subscription


class Command(BaseCommand):
    help = ("A command to add subscription metadata in order to "
            " inform subscribers of new or changed features.")

    def add_arguments(self, parser):
        parser.add_argument(
            '--audio-file',
            dest="audio_file",
            type=str,
            required=True,
            help='A path to the audio file containing the "\
            "notification message'
        )
        parser.add_argument(
            '--message-set',
            dest="message_set",
            type=str,
            help='A string to filter the messagesets by name, only update '
            'subscriptions linked to these.'
        )

    def handle(self, *args, **options):
        audio_file = options['audio_file']
        message_set = options['message_set']

        active_subscriptions = Subscription.objects.filter(
            active=True,
            messageset__content_type="audio")

        if message_set:
            active_subscriptions = active_subscriptions.filter(
                messageset__short_name__contains=message_set)

        count = 0
        for active_subscription in active_subscriptions.iterator():

            if not active_subscription.metadata:
                active_subscription.metadata = {}

            if (active_subscription.metadata.get("prepend_next_delivery")
                    is not None):
                continue

            active_subscription.metadata["prepend_next_delivery"] = \
                audio_file.format(**model_to_dict(active_subscription))
            active_subscription.save()

            count += 1

        self.success(
            "Updated {} subscription(s) with audio notifications.".format(
                count))

    def log(self, level, msg):
        self.stdout.write(level(msg))

    def success(self, msg):
        self.log(self.style.SUCCESS, msg)
